from a10sdk.common.A10BaseClass import A10BaseClass


class EthernetCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param flap_ethernet_end: {"type": "number", "description": "Ethernet Port", "format": "interface"}
    :param flap_ethernet_start: {"type": "number", "description": "Ethernet Port", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ethernet-cfg"
        self.DeviceProxy = ""
        self.flap_ethernet_end = ""
        self.flap_ethernet_start = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RestartPortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "flap-ethernet-end": {"type": "number", "description": "Ethernet Port", "format": "interface"}, "flap-ethernet-start": {"type": "number", "description": "Ethernet Port", "format": "interface"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "restart-port-list"
        self.DeviceProxy = ""
        self.ethernet_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VrrpA(A10BaseClass):
    
    """Class Description::
    HA VRRP-A Global Commands.

    Class vrrp-a supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vrid_list: {"minItems": 1, "items": {"type": "vrid"}, "uniqueItems": true, "array": [{"required": ["vrid-val"], "properties": {"preempt-mode": {"type": "object", "properties": {"threshold": {"description": "preemption threshold (preemption threshhold (1-255), default 1)", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "disable": {"default": 0, "type": "number", "description": "disable preemption", "format": "flag"}}}, "blade-parameters": {"type": "object", "properties": {"priority": {"description": "VRRP-A priorty (Priority, default is 150)", "format": "number", "default": 150, "maximum": 255, "minimum": 1, "type": "number"}, "fail-over-policy-template": {"description": "Apply a fail over policy template (VRRP-A fail over policy template name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/vrrp-a/fail-over-policy-template"}, "tracking-options": {"type": "object", "properties": {"interface": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet Interface (Ethernet interface number)", "format": "interface"}, "optional": true, "priority-cost": {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}, "route": {"type": "object", "properties": {"ipv6-destination-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Route's administrative distance (default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "v6mask": {"description": "IPv6 Destination Prefix", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}, "protocol": {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}, "priority-cost": {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "ipv6-destination": {"type": "string", "description": "IPv6 Destination Prefix", "format": "ipv6-address"}, "gatewayv6": {"type": "string", "description": "Match the route's gateway (next-hop) (default: match any)", "format": "ipv6-address"}, "optional": true}}]}, "ip-destination-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Route's administrative distance (default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "protocol": {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}, "mask": {"type": "string", "description": "Destination prefix mask", "format": "ipv4-netmask"}, "priority-cost": {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "ip-destination": {"type": "string", "description": "Destination prefix", "format": "ipv4-address"}, "optional": true, "gateway": {"type": "string", "description": "Match the route's gateway (next-hop) (default: match any)", "format": "ipv4-address"}}}]}}}, "vlan-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"vlan": {"description": "VLAN tracking (VLAN id)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}, "optional": true, "timeout": {"minimum": 2, "type": "number", "maximum": 600, "format": "number"}, "priority-cost": {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}, "trunk-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"per-port-pri": {"description": "per port priority", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "priority-cost": {"description": "The amount the priority will decrease", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "trunk": {"description": "trunk tracking (Trunk Number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}}}]}, "gateway": {"type": "object", "properties": {"ipv4-gateway-list": {"minItems": 1, "items": {"type": "ipv4-gateway"}, "uniqueItems": true, "array": [{"required": ["ip-address"], "properties": {"ip-address": {"optional": false, "type": "string", "description": "IP Address", "format": "ipv4-address"}, "priority-cost": {"description": "The amount the priority will decrease", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/vrid/{vrid-val}/blade-parameters/tracking-options/gateway/ipv4-gateway/{ip-address}"}, "ipv6-gateway-list": {"minItems": 1, "items": {"type": "ipv6-gateway"}, "uniqueItems": true, "array": [{"required": ["ipv6-address"], "properties": {"ipv6-address": {"optional": false, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "priority-cost": {"description": "The amount the priority will decrease", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/vrid/{vrid-val}/blade-parameters/tracking-options/gateway/ipv6-gateway/{ipv6-address}"}}}}}}}, "floating-ip": {"type": "object", "properties": {"ipv6-address-part-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet (for link-local address only)", "format": "interface"}, "ipv6-address-partition": {"partition-visibility": "private", "platform-specific-default": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "optional": true, "ve": {"description": "VE interface (for link-local address only)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}, "trunk": {"description": "Trunk interface (for link-local address only)", "minimum": 1, "type": "number", "maximum": 4096, "format": "number"}}}]}, "ip-address-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ip-address": {"partition-visibility": "shared", "platform-specific-default": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}}}]}, "ip-address-part-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip-address-partition": {"partition-visibility": "private", "platform-specific-default": 1, "type": "string", "description": "IP Address", "format": "ipv4-address"}, "optional": true}}]}, "ipv6-address-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-address": {"partition-visibility": "shared", "platform-specific-default": 1, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "ethernet": {"type": "number", "description": "Ethernet (for link-local address only)", "format": "interface"}, "optional": true, "ve": {"description": "VE interface (for link-local address only)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}, "trunk": {"description": "Trunk interface (for link-local address only)", "minimum": 1, "type": "number", "maximum": 4096, "format": "number"}}}]}}}, "vrid-val": {"description": "Specify ha VRRP-A vrid", "format": "number", "default": 0, "optional": false, "maximum": 31, "minimum": 0, "type": "number"}, "follow": {"type": "object", "properties": {"vrid-lead": {"description": "Define a VRRP-A VRID leader", "partition-visibility": "private", "minLength": 1, "format": "string", "maxLength": 128, "type": "string"}}}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/vrid/{vrid-val}"}
    :param force_self_standby_persistent_list: {"minItems": 1, "items": {"type": "force-self-standby-persistent"}, "uniqueItems": true, "array": [{"required": ["vrid"], "properties": {"vrid": {"description": "Specify one VRRP-A vrid to force into standby state", "format": "number", "type": "number", "maximum": 31, "minimum": 0, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/force-self-standby-persistent/{vrid}"}
    :param fail_over_policy_template_list: {"minItems": 1, "items": {"type": "fail-over-policy-template"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"vlan-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"vlan": {"description": "VLAN tracking (VLAN id)", "minimum": 1, "type": "number", "maximum": 4094, "format": "number"}, "optional": true, "weight": {"description": "The failover event weight", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "timeout": {"minimum": 2, "type": "number", "maximum": 600, "format": "number"}}}]}, "name": {"description": "VRRP-A fail over policy template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}, "route": {"type": "object", "properties": {"ipv6-destination-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Route's administrative distance (default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "v6mask": {"description": "IPv6 Destination Prefix", "minimum": 0, "type": "number", "maximum": 128, "format": "number"}, "protocol": {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}, "weight": {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "ipv6-destination": {"type": "string", "description": "IPv6 Destination Prefix", "format": "ipv6-address"}, "gatewayv6": {"type": "string", "description": "Match the route's gateway (next-hop) (default: match any)", "format": "ipv6-address"}, "optional": true}}]}, "ip-destination-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Route's administrative distance(default: match any)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "protocol": {"enum": ["any", "static", "dynamic"], "type": "string", "description": "'any': Match any routing protocol (default); 'static': Match only static routes (added by user); 'dynamic': Match routes added by dynamic routing protocols (e.g. OSPF); ", "format": "enum"}, "weight": {"description": "The amount the priority will decrease if the route is missing (The amount the priority will decrease if the route is not present)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "mask": {"type": "string", "description": "Destination prefix mask", "format": "ipv4-netmask"}, "ip-destination": {"type": "string", "description": "Destination prefix", "format": "ipv4-address"}, "optional": true, "gateway": {"type": "string", "format": "ipv4-address"}}}]}}}, "interface": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet Interface (Ethernet interface number)", "format": "interface"}, "optional": true, "weight": {"description": "The failover event weight", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}, "gateway": {"type": "object", "properties": {"gw-ipv4-address-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "weight": {"description": "The failover event weight", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "gw-ipv4-address": {"type": "string", "description": "IP Address", "format": "ipv4-address"}}}]}, "gw-ipv6-address-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "gw-ipv6-address": {"type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "weight": {"description": "The failover event weight", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}}}]}}}, "trunk-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"per-port-weight": {"description": "Per port failover weight", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "optional": true, "weight": {"description": "failover event weight", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "trunk": {"description": "trunk tracking (trunk id)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}}}]}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/fail-over-policy-template/{name}"}
    :param vrid_lead_list: {"minItems": 1, "items": {"type": "vrid-lead"}, "uniqueItems": true, "array": [{"required": ["vrid-lead-str"], "properties": {"vrid-lead-str": {"description": "VRRP-A VRID leader name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "partition": {"type": "object", "properties": {"shared-cfg": {"type": "object", "properties": {"shared": {"default": 0, "not": "name", "type": "number", "description": "Shared partition", "format": "flag"}, "vrid": {"default": 0, "type": "number", "description": "VRRP-A id", "format": "flag"}, "vrid-value": {"description": "Specify ha VRRP-A vrid", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}}}, "name-cfg": {"type": "object", "properties": {"vrid-value": {"description": "Specify ha VRRP-A vrid", "minimum": 0, "type": "number", "maximum": 7, "format": "number"}, "vrid": {"default": 0, "type": "number", "description": "VRRP-A id", "format": "flag"}, "name": {"description": "Partition name", "format": "string", "minLength": 1, "maxLength": 14, "not": "shared", "type": "string"}}}, "partition": {"default": 0, "type": "number", "description": "Partition name", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/vrrp-a/vrid-lead/{vrid-lead-str}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vrrp-a"
        self.a10_url="/axapi/v3/vrrp-a"
        self.DeviceProxy = ""
        self.vrid_list = []
        self.force_self_standby_persistent_list = []
        self.force_self_standby = {}
        self.peer_group = {}
        self.fail_over_policy_template_list = []
        self.vrid_lead_list = []
        self.common = {}
        self.interface = {}
        self.restart_port_list = {}
        self.preferred_session_sync_port = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Event(A10BaseClass):
    
    """Class Description::
    configure event actions.

    Class event supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param partition_list: {"minItems": 1, "items": {"type": "partition"}, "uniqueItems": true, "array": [{"required": ["vnp-events"], "properties": {"vnp-events": {"optional": false, "enum": ["part-create", "part-del"], "type": "string", "description": "'part-create': Create new partition; 'part-del': Delete a partition; ", "format": "enum"}, "logging": {"optional": true, "enum": ["on", "off"], "type": "string", "description": "'on': enable this action; 'off': disable this action; ", "format": "enum"}, "email": {"optional": true, "enum": ["on", "off"], "type": "string", "description": "'on': enable this action; 'off': disable this action; ", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/event/partition/{vnp-events}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/event`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "event"
        self.a10_url="/axapi/v3/event"
        self.DeviceProxy = ""
        self.partition_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Login_auth_req: {"description": "Login Authentication Request", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param SLO_error: {"description": "Single Logout Error", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param SP_metadata_export_success: {"description": "Metadata Export Success", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param SLO_req: {"description": "Single Logout Request", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param Login_auth_resp: {"description": "Login Authentication Response", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param SLO_success: {"description": "Single Logout Success", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param ACS_success: {"description": "Assertion Consuming Service Success", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param ACS_error: {"description": "Assertion Consuming Service Error", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param Other_error: {"description": "Other Error", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param ACS_req: {"description": "Assertion Consuming Service Request", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param SP_metadata_export_req: {"description": "Metadata Export Request", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Login_auth_req = ""
        self.SLO_error = ""
        self.SP_metadata_export_success = ""
        self.SLO_req = ""
        self.Login_auth_resp = ""
        self.SLO_success = ""
        self.ACS_success = ""
        self.ACS_error = ""
        self.Other_error = ""
        self.ACS_req = ""
        self.SP_metadata_export_req = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceProvider(A10BaseClass):
    
    """Class Description::
    Statistics for the object service-provider.

    Class service-provider supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify SAML authentication service provider name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/saml/service-provider/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "service-provider"
        self.a10_url="/axapi/v3/aam/authentication/saml/service-provider/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Common(A10BaseClass):
    
    """Class Description::
    SLB related commands.

    Class common supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param stats_data_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable global slb data statistics", "format": "flag"}
    :param compress_block_size: {"description": "Set compression block size (Compression block size in bytes)", "format": "number", "type": "number", "maximum": 131008, "minimum": 6000, "optional": true}
    :param dns_cache_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable DNS cache", "format": "flag"}
    :param msl_time: {"description": "Configure maximum session life, default is 2 seconds (1-40 seconds, default is 2 seconds)", "format": "number", "default": 2, "optional": true, "maximum": 40, "minimum": 1, "type": "number"}
    :param graceful_shutdown_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable graceful shutdown", "format": "flag"}
    :param buff_thresh_hw_buff: {"description": "Set hardware buffer threshold", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}
    :param hw_syn_rr: {"description": "Configure hardware SYN round robin (range 1-500000)", "format": "number", "type": "number", "maximum": 500000, "minimum": 1, "optional": true}
    :param entity: {"optional": true, "enum": ["server", "virtual-server"], "type": "string", "description": "'server': Graceful shutdown server/port only; 'virtual-server': Graceful shutdown virtual server/port only; ", "format": "enum"}
    :param rate_limit_logging: {"default": 0, "optional": true, "type": "number", "description": "Configure rate limit logging", "format": "flag"}
    :param scale_out: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB scale out", "format": "flag"}
    :param graceful_shutdown: {"description": "1-65535, in unit of seconds", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param exclude_destination: {"optional": true, "enum": ["local", "remote"], "type": "string", "description": "'local': Maximum local rate; 'remote': Maximum remote rate;  (Maximum rates)", "format": "enum"}
    :param fast_path_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable fast path in SLB processing", "format": "flag"}
    :param drop_icmp_to_vip_when_vip_down: {"default": 0, "optional": true, "type": "number", "description": "Drop ICMP to VIP when VIP down", "format": "flag"}
    :param buff_thresh: {"default": 0, "optional": true, "type": "number", "description": "Set buffer threshold", "format": "flag"}
    :param hw_compression: {"default": 0, "optional": true, "type": "number", "description": "Use hardware compression", "format": "flag"}
    :param extended_stats: {"default": 0, "optional": true, "type": "number", "description": "Enable global slb extended statistics", "format": "flag"}
    :param buff_thresh_sys_buff_low: {"description": "Set low water mark of system buffer", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}
    :param after_disable: {"default": 0, "optional": true, "type": "number", "description": "Graceful shutdown after disable server/port and/or virtual server/port", "format": "flag"}
    :param max_local_rate: {"description": "Set maximum local rate", "format": "number", "default": 32, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param dns_cache_age: {"description": "Set DNS cache entry age, default is 300 seconds (1-1000000 seconds, default is 300 seconds)", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}
    :param max_http_header_count: {"description": "Set maximum number of HTTP headers allowed", "partition-visibility": "shared", "default": 90, "optional": true, "format": "number", "maximum": 255, "minimum": 90, "type": "number"}
    :param l2l3_trunk_lb_disable: {"description": "Disable L2/L3 trunk LB", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param sort_res: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB sorting of resource names", "format": "flag"}
    :param snat_gwy_for_l3: {"default": 0, "optional": true, "type": "number", "description": "Use source NAT gateway for L3 traffic", "format": "flag"}
    :param buff_thresh_relieve_thresh: {"description": "Relieve threshold", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}
    :param dsr_health_check_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable dsr-health-check (direct server return health check)", "format": "flag"}
    :param dns_vip_stateless: {"description": "Enable DNS VIP stateless mode", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}
    :param dns_cache_entry_size: {"description": "Set DNS cache entry size, default is 256 bytes (1-4096 bytes, default is 256 bytes)", "format": "number", "default": 256, "optional": true, "maximum": 4096, "minimum": 1, "type": "number"}
    :param buff_thresh_sys_buff_high: {"description": "Set high water mark of system buffer", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}
    :param max_buff_queued_per_conn: {"description": "Set per connection buffer threshold (Buffer value range 128-4096)", "partition-visibility": "shared", "optional": true, "format": "number", "maximum": 4096, "minimum": 128, "type": "number"}
    :param max_remote_rate: {"description": "Set maximum remote rate", "format": "number", "default": 15000, "optional": true, "maximum": 1000000, "minimum": 1, "type": "number"}
    :param ttl_threshold: {"description": "Only cache DNS response with longer TTL", "format": "number", "type": "number", "maximum": 10000000, "minimum": 1, "optional": true}
    :param response_type: {"optional": true, "enum": ["single-answer", "round-robin"], "type": "string", "description": "'single-answer': Only cache DNS response with single answer; 'round-robin': Round robin; ", "format": "enum"}
    :param enable_l7_req_acct: {"default": 0, "optional": true, "type": "number", "description": "Enable L7 request accounting", "format": "flag"}
    :param snat_on_vip: {"default": 0, "optional": true, "type": "number", "description": "Enable source NAT traffic against VIP", "format": "flag"}
    :param disable_server_auto_reselect: {"default": 0, "optional": true, "type": "number", "description": "Disable auto reselection of server", "format": "flag"}
    :param interval: {"description": "Specify the healthcheck interval, default is 5 seconds (Interval Value, in seconds (default 5))", "format": "number", "type": "number", "maximum": 180, "minimum": 1, "optional": true}
    :param gateway_health_check: {"default": 0, "optional": true, "type": "number", "description": "Enable gateway health check", "format": "flag"}
    :param mss_table: {"description": "Set MSS table (128-750, default is 536)", "partition-visibility": "shared", "default": 536, "optional": true, "format": "number", "maximum": 750, "minimum": 128, "type": "number"}
    :param timeout: {"description": "Specify the healthcheck timeout value, default is 15 seconds (Timeout Value, in seconds (default 15))", "format": "number", "default": 15, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}
    :param use_mss_tab: {"default": 0, "optional": true, "type": "number", "description": "Use MSS based on internal table for SLB processing", "format": "flag"}
    :param reset_stale_session: {"default": 0, "optional": true, "type": "number", "description": "Send reset if session in delete queue receives a SYN packet", "format": "flag"}
    :param no_auto_up_on_aflex: {"default": 0, "optional": true, "type": "number", "description": "Don't automatically mark vport up when aFleX is bound", "format": "flag"}
    :param software: {"default": 0, "optional": true, "type": "number", "description": "Software", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/common`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "common"
        self.a10_url="/axapi/v3/slb/common"
        self.DeviceProxy = ""
        self.stats_data_disable = ""
        self.compress_block_size = ""
        self.dns_cache_enable = ""
        self.msl_time = ""
        self.graceful_shutdown_enable = ""
        self.buff_thresh_hw_buff = ""
        self.hw_syn_rr = ""
        self.entity = ""
        self.rate_limit_logging = ""
        self.scale_out = ""
        self.graceful_shutdown = ""
        self.exclude_destination = ""
        self.fast_path_disable = ""
        self.drop_icmp_to_vip_when_vip_down = ""
        self.buff_thresh = ""
        self.hw_compression = ""
        self.extended_stats = ""
        self.buff_thresh_sys_buff_low = ""
        self.after_disable = ""
        self.max_local_rate = ""
        self.dns_cache_age = ""
        self.max_http_header_count = ""
        self.l2l3_trunk_lb_disable = ""
        self.sort_res = ""
        self.snat_gwy_for_l3 = ""
        self.buff_thresh_relieve_thresh = ""
        self.dsr_health_check_enable = ""
        self.dns_vip_stateless = ""
        self.dns_cache_entry_size = ""
        self.buff_thresh_sys_buff_high = ""
        self.max_buff_queued_per_conn = ""
        self.max_remote_rate = ""
        self.ttl_threshold = ""
        self.response_type = ""
        self.enable_l7_req_acct = ""
        self.snat_on_vip = ""
        self.disable_server_auto_reselect = ""
        self.interval = ""
        self.gateway_health_check = ""
        self.conn_rate_limit = {}
        self.mss_table = ""
        self.timeout = ""
        self.use_mss_tab = ""
        self.reset_stale_session = ""
        self.no_auto_up_on_aflex = ""
        self.software = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ptr_memory: {"type": "number", "format": "number"}
    :param total_memory: {"type": "number", "format": "number"}
    :param reference_objects: {"type": "number", "format": "number"}
    :param mx_objects: {"type": "number", "format": "number"}
    :param ds_objects: {"type": "number", "format": "number"}
    :param nsec_objects: {"type": "number", "format": "number"}
    :param array_memory: {"type": "number", "format": "number"}
    :param nsec3param_objects: {"type": "number", "format": "number"}
    :param srv_memory: {"type": "number", "format": "number"}
    :param reference_memory: {"type": "number", "format": "number"}
    :param srv_objects: {"type": "number", "format": "number"}
    :param table_memory: {"type": "number", "format": "number"}
    :param a_objects: {"type": "number", "format": "number"}
    :param ns_memory: {"type": "number", "format": "number"}
    :param aaaa_memory: {"type": "number", "format": "number"}
    :param zone_objects: {"type": "number", "format": "number"}
    :param table_objects: {"type": "number", "format": "number"}
    :param mx_memory: {"type": "number", "format": "number"}
    :param soa_memory: {"type": "number", "format": "number"}
    :param domain_objects: {"type": "number", "format": "number"}
    :param nsec_memory: {"type": "number", "format": "number"}
    :param nsec3_objects: {"type": "number", "format": "number"}
    :param a_memory: {"type": "number", "format": "number"}
    :param array_objects: {"type": "number", "format": "number"}
    :param total_objects: {"type": "number", "format": "number"}
    :param soa_objects: {"type": "number", "format": "number"}
    :param ds_memory: {"type": "number", "format": "number"}
    :param cname_objects: {"type": "number", "format": "number"}
    :param domain_memory: {"type": "number", "format": "number"}
    :param nsec3param_memory: {"type": "number", "format": "number"}
    :param txt_memory: {"type": "number", "format": "number"}
    :param dnskey_memory: {"type": "number", "format": "number"}
    :param ns_objects: {"type": "number", "format": "number"}
    :param ptr_objects: {"type": "number", "format": "number"}
    :param aaaa_objects: {"type": "number", "format": "number"}
    :param cname_memory: {"type": "number", "format": "number"}
    :param txt_objects: {"type": "number", "format": "number"}
    :param rrsig_objects: {"type": "number", "format": "number"}
    :param rrsig2_memory: {"type": "number", "format": "number"}
    :param nsec3_memory: {"type": "number", "format": "number"}
    :param zone_memory: {"type": "number", "format": "number"}
    :param rrsig2_objects: {"type": "number", "format": "number"}
    :param rrsig_memory: {"type": "number", "format": "number"}
    :param dnskey_objects: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.ptr_memory = ""
        self.total_memory = ""
        self.reference_objects = ""
        self.mx_objects = ""
        self.ds_objects = ""
        self.nsec_objects = ""
        self.array_memory = ""
        self.nsec3param_objects = ""
        self.srv_memory = ""
        self.reference_memory = ""
        self.srv_objects = ""
        self.table_memory = ""
        self.a_objects = ""
        self.ns_memory = ""
        self.aaaa_memory = ""
        self.zone_objects = ""
        self.table_objects = ""
        self.mx_memory = ""
        self.soa_memory = ""
        self.domain_objects = ""
        self.nsec_memory = ""
        self.nsec3_objects = ""
        self.a_memory = ""
        self.array_objects = ""
        self.total_objects = ""
        self.soa_objects = ""
        self.ds_memory = ""
        self.cname_objects = ""
        self.domain_memory = ""
        self.nsec3param_memory = ""
        self.txt_memory = ""
        self.dnskey_memory = ""
        self.ns_objects = ""
        self.ptr_objects = ""
        self.aaaa_objects = ""
        self.cname_memory = ""
        self.txt_objects = ""
        self.rrsig_objects = ""
        self.rrsig2_memory = ""
        self.nsec3_memory = ""
        self.zone_memory = ""
        self.rrsig2_objects = ""
        self.rrsig_memory = ""
        self.dnskey_objects = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dnssec(A10BaseClass):
    
    """Class Description::
    Operational Status for the object dnssec.

    Class dnssec supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/dnssec/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dnssec"
        self.a10_url="/axapi/v3/dnssec/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class FloatingIpCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param floating_ip_mask: {"type": "string", "description": "Netmask", "format": "ipv4-netmask"}
    :param floating_ip: {"type": "string", "description": "Floating IP address (IPv4 address)", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "floating-ip-cfg"
        self.DeviceProxy = ""
        self.floating_ip_mask = ""
        self.floating_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vcs(A10BaseClass):
    
    """Class Description::
    Virtual Chassis System.

    Class vcs supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param multicast_port: {"description": "Port used in multicast communication (Port number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param dead_interval: {"description": "The node will be considered dead as lack of hearbeats after this time (in unit of second, 10 by default)", "format": "number", "default": 10, "optional": true, "maximum": 240, "minimum": 5, "type": "number"}
    :param force_wait_interval: {"description": "The node will wait the specified time interval before it start aVCS (in unit of second (default is 5))", "format": "number", "default": 5, "optional": true, "maximum": 240, "minimum": 5, "type": "number"}
    :param ssl_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable SSL", "format": "flag"}
    :param multicast_ipv6: {"not": "multicast-ip", "optional": true, "type": "string", "description": "Multicast (group) IPv6 address (Multicast IPv6 address)", "format": "ipv6-address"}
    :param floating_ip_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"floating-ip-mask": {"type": "string", "description": "Netmask", "format": "ipv4-netmask"}, "floating-ip": {"type": "string", "description": "Floating IP address (IPv4 address)", "format": "ipv4-address"}, "optional": true}}]}
    :param device_list: {"minItems": 1, "items": {"type": "device"}, "uniqueItems": true, "array": [{"required": ["device"], "properties": {"management": {"default": 0, "optional": true, "type": "number", "description": "Management interface", "format": "flag"}, "ethernet-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet (Ethernet interface number)", "format": "interface"}, "optional": true}}]}, "priority": {"description": "Device priority", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "enable": {"default": 0, "optional": true, "type": "number", "description": "Enable", "format": "flag"}, "ve-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ve": {"description": "VE interface (VE interface number)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}}}]}, "device": {"description": "Device ID", "format": "number", "type": "number", "maximum": 8, "minimum": 1, "optional": false}, "affinity-vrrp-a-vrid": {"description": "vrid-group", "format": "number", "type": "number", "maximum": 31, "minimum": 0, "optional": true}, "unicast-port": {"description": "Port used in unicast communication (Port number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1024, "optional": true}, "trunk-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "trunk": {"description": "Trunk interface (Trunk interface number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}}}]}}}], "type": "array", "$ref": "/axapi/v3/vcs/device/{device}"}
    :param time_interval: {"description": "how long between heartbeats (in unit of second, default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}
    :param action: {"description": "'enable': enable VCS; 'disable': disable VCS; ", "format": "enum", "default": "disable", "type": "string", "enum": ["enable", "disable"], "optional": true}
    :param failure_retry_count: {"description": "VCS retry count after fails to join the chassis (0-255, default is 2  means retry forever)", "format": "number", "default": 2, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}
    :param multicast_ip: {"not": "multicast-ipv6", "optional": true, "type": "string", "description": "Multicast (group) IP address (Multicast IP address)", "format": "ipv4-address"}
    :param config_seq: {"description": "Configuration sequence number", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vcs`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vcs"
        self.a10_url="/axapi/v3/vcs"
        self.DeviceProxy = ""
        self.multicast_port = ""
        self.dead_interval = ""
        self.force_wait_interval = ""
        self.ssl_enable = ""
        self.debug = {}
        self.multicast_ipv6 = ""
        self.vmaster_take_over = {}
        self.floating_ip_cfg = []
        self.device_list = []
        self.A10WW_reload = {}
        self.time_interval = ""
        self.admin_session_connect = {}
        self.action = ""
        self.vMaster_maintenance = {}
        self.failure_retry_count = ""
        self.multicast_ip = ""
        self.config_seq = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CpuUsage(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cpu_id: {"type": "number", "format": "number"}
    :param 30_sec: {"type": "number", "format": "number"}
    :param 60_sec: {"type": "number", "format": "number"}
    :param 10_sec: {"type": "number", "format": "number"}
    :param 5_sec: {"type": "number", "format": "number"}
    :param 1_sec: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cpu-usage"
        self.DeviceProxy = ""
        self.cpu_id = ""
        self.A10WW_30_sec = ""
        self.A10WW_60_sec = ""
        self.A10WW_10_sec = ""
        self.A10WW_5_sec = ""
        self.A10WW_1_sec = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cpu_usage: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cpu-id": {"type": "number", "format": "number"}, "30-sec": {"type": "number", "format": "number"}, "optional": true, "60-sec": {"type": "number", "format": "number"}, "10-sec": {"type": "number", "format": "number"}, "5-sec": {"type": "number", "format": "number"}, "1-sec": {"type": "number", "format": "number"}}}]}
    :param number_of_cpu: {"type": "number", "format": "number"}
    :param current_time: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.cpu_usage = []
        self.number_of_cpu = ""
        self.current_time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CtrlCpu(A10BaseClass):
    
    """Class Description::
    Operational Status for the object ctrl-cpu.

    Class ctrl-cpu supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/ctrl-cpu/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ctrl-cpu"
        self.a10_url="/axapi/v3/system/ctrl-cpu/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Num_hardware_devices: {"type": "number", "format": "number"}
    :param IPsec_mode: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param IKE_Gateway_total: {"type": "number", "format": "number"}
    :param IPsec_SA_total: {"type": "number", "format": "number"}
    :param Crypto_cores_assigned_to_IPsec: {"type": "number", "format": "number"}
    :param IKE_SA_total: {"type": "number", "format": "number"}
    :param Crypto_cores_total: {"type": "number", "format": "number"}
    :param IPsec_total: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.Num_hardware_devices = ""
        self.IPsec_mode = ""
        self.IKE_Gateway_total = ""
        self.IPsec_SA_total = ""
        self.Crypto_cores_assigned_to_IPsec = ""
        self.IKE_SA_total = ""
        self.Crypto_cores_total = ""
        self.IPsec_total = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vpn(A10BaseClass):
    
    """Class Description::
    Operational Status for the object vpn.

    Class vpn supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ike_gateway_list: {"minItems": 1, "items": {"type": "ike-gateway"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"oper": {"type": "object", "properties": {"Status": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Remote-IP": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Hash": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Encryption": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Responder-SPI": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Local-IP": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Lifetime": {"type": "number", "format": "number"}, "Initiator-SPI": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}, "name": {"description": "IKE-gateway name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/vpn/ike-gateway/{name}"}
    :param ipsec_list: {"minItems": 1, "items": {"type": "ipsec"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"oper": {"type": "object", "properties": {"Hash-Algorithm": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Protocol": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "DH-Group": {"type": "number", "format": "number"}, "Peer-IP": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Local-IP": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Anti-Replay": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Lifebytes": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "NAT-Traversal": {"type": "number", "format": "number"}, "SA-Index": {"type": "number", "format": "number"}, "Remote-SPI": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Mode": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Encryption-Algorithm": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Local-SPI": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Lifetime": {"type": "number", "format": "number"}}}, "name": {"description": "IPsec name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 31, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/vpn/ike-gateway/{name}/ipsec/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vpn"
        self.a10_url="/axapi/v3/vpn/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.ike_gateway_list = []
        self.ipsec_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param es_resp_invalid_http: {"optional": true, "size": "8", "type": "number", "oid": "19", "format": "counter"}
    :param curr_req: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param total_rev_pkts_inspected_good_status_code: {"optional": true, "size": "8", "type": "number", "oid": "21", "format": "counter"}
    :param es_resp_count: {"optional": true, "size": "8", "type": "number", "oid": "18", "format": "counter"}
    :param total_fwd_bytes: {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}
    :param es_resp_other: {"optional": true, "size": "8", "type": "number", "oid": "16", "format": "counter"}
    :param fastest_rsp_time: {"optional": true, "size": "8", "type": "number", "oid": "23", "format": "counter"}
    :param total_fwd_pkts: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param es_req_count: {"optional": true, "size": "8", "type": "number", "oid": "17", "format": "counter"}
    :param es_resp_500: {"optional": true, "size": "8", "type": "number", "oid": "15", "format": "counter"}
    :param peak_conn: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param total_req: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param es_resp_400: {"optional": true, "size": "8", "type": "number", "oid": "14", "format": "counter"}
    :param es_resp_300: {"optional": true, "size": "8", "type": "number", "oid": "13", "format": "counter"}
    :param curr_conn: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param es_resp_200: {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}
    :param total_rev_bytes: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param response_time: {"optional": true, "size": "8", "type": "number", "oid": "22", "format": "counter"}
    :param total_conn: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param total_rev_pkts: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param total_req_succ: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param last_total_conn: {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}
    :param total_rev_pkts_inspected: {"optional": true, "size": "8", "type": "number", "oid": "20", "format": "counter"}
    :param slowest_rsp_time: {"optional": true, "size": "8", "type": "number", "oid": "24", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.es_resp_invalid_http = ""
        self.curr_req = ""
        self.total_rev_pkts_inspected_good_status_code = ""
        self.es_resp_count = ""
        self.total_fwd_bytes = ""
        self.es_resp_other = ""
        self.fastest_rsp_time = ""
        self.total_fwd_pkts = ""
        self.es_req_count = ""
        self.es_resp_500 = ""
        self.peak_conn = ""
        self.total_req = ""
        self.es_resp_400 = ""
        self.es_resp_300 = ""
        self.curr_conn = ""
        self.es_resp_200 = ""
        self.total_rev_bytes = ""
        self.response_time = ""
        self.total_conn = ""
        self.total_rev_pkts = ""
        self.total_req_succ = ""
        self.last_total_conn = ""
        self.total_rev_pkts_inspected = ""
        self.slowest_rsp_time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Port(A10BaseClass):
    
    """Class Description::
    Statistics for the object port.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param protocol: {"enum": ["tcp", "udp"], "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}
    :param port_number: {"description": "Port Number", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/server/{name}/port/{port_number}+{protocol}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_number","protocol"]

        self.b_key = "port"
        self.a10_url="/axapi/v3/cgnv6/server/{name}/port/{port_number}+{protocol}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.protocol = ""
        self.port_number = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param limit_total_drop: {"description": "Total rate limit drops", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param v6_limit_intf_drop: {"description": "Interfaces rate limit drops (v6)", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param limit_vserver_drop: {"description": "Virtual Server rate limit drops", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param v6_limit_vserver_drop: {"description": "Virtual Server rate limit drops (v6)", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param over_limit_drop: {"description": "Over limit drops", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param v6_lockup_time_left: {"description": "Lockup time left (v6)", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param v6_limit_total_drop: {"description": "Total rate limit drops (v6)", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param v6_curr_rate: {"description": "Current rate (v6)", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param lockup_time_left: {"description": "Lockup time left", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param limit_intf_drop: {"description": "Interfaces rate limit drops", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param curr_rate: {"description": "Current rate", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param v6_over_limit_drop: {"description": "Over limit drops (v6)", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.limit_total_drop = ""
        self.v6_limit_intf_drop = ""
        self.limit_vserver_drop = ""
        self.v6_limit_vserver_drop = ""
        self.over_limit_drop = ""
        self.v6_lockup_time_left = ""
        self.v6_limit_total_drop = ""
        self.v6_curr_rate = ""
        self.lockup_time_left = ""
        self.limit_intf_drop = ""
        self.curr_rate = ""
        self.v6_over_limit_drop = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IcmpRate(A10BaseClass):
    
    """Class Description::
    Statistics for the object icmp-rate.

    Class icmp-rate supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/icmp-rate/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "icmp-rate"
        self.a10_url="/axapi/v3/system/icmp-rate/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port: {"type": "number", "description": "Single Destination Port or Port Range Start", "format": "number"}
    :param port_end: {"type": "number", "description": "Port Range End", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-list"
        self.DeviceProxy = ""
        self.port = ""
        self.port_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Tcp(A10BaseClass):
    
    """Class Description::
    Set behavior for TCP only.

    Class tcp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "port": {"type": "number", "description": "Single Destination Port or Port Range Start", "format": "number"}, "port-end": {"type": "number", "description": "Port Range End", "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/port-overloading/tcp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "tcp"
        self.a10_url="/axapi/v3/cgnv6/lsn/port-overloading/tcp"
        self.DeviceProxy = ""
        self.port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Erase(A10BaseClass):
    
    """    :param preserve_accounts: {"description": "preserve admin accounts", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param reload: {"description": "reload after erase", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param preserve_management: {"description": "preserve managememt ip and default gateway", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Erase Configuration.

    Class erase supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/erase`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "erase"
        self.a10_url="/axapi/v3/erase"
        self.DeviceProxy = ""
        self.preserve_accounts = ""
        self.A10WW_reload = ""
        self.preserve_management = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv4List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param lid: {"description": "Use Limit ID defined in template (Specify LID index)", "format": "number", "maximum": 31, "minimum": 1, "not": "glid", "type": "number"}
    :param glid: {"description": "Use global Limit ID (Specify global LID index)", "format": "number", "maximum": 1023, "minimum": 1, "not": "lid", "type": "number"}
    :param age: {"description": "Specify age in minutes", "minimum": 1, "type": "number", "maximum": 2000, "format": "number"}
    :param ipv4addr: {"type": "string", "description": "Specify IP address", "format": "ipv4-cidr"}
    :param lsn_lid: {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}
    :param lsn_radius_profile: {"description": "LSN RADIUS Profile Index", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv4-list"
        self.DeviceProxy = ""
        self.lid = ""
        self.glid = ""
        self.age = ""
        self.ipv4addr = ""
        self.lsn_lid = ""
        self.lsn_radius_profile = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class StrList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param str: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify key string", "format": "string-rlx"}
    :param value_str: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify value string", "format": "string"}
    :param str_glid_dummy: {"default": 0, "not": "str-lid-dummy", "type": "number", "description": "Use global Limit ID", "format": "flag"}
    :param str_glid: {"description": "Global LID index", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}
    :param str_lid_dummy: {"default": 0, "not": "str-glid-dummy", "type": "number", "description": "Use Limit ID defined in template", "format": "flag"}
    :param str_lid: {"description": "LID index", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "str-list"
        self.DeviceProxy = ""
        self.A10WW_str = ""
        self.value_str = ""
        self.str_glid_dummy = ""
        self.str_glid = ""
        self.str_lid_dummy = ""
        self.str_lid = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AcList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ac_match_type: {"enum": ["contains", "ends-with", "equals", "starts-with"], "type": "string", "description": "'contains': String contains another string; 'ends-with': String ends with another string; 'equals': String equals another string; 'starts-with': String starts with another string; ", "format": "enum"}
    :param ac_key_string: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify key string", "format": "string-rlx"}
    :param ac_value: {"minLength": 1, "maxLength": 639, "type": "string", "description": "Specify value string", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ac-list"
        self.DeviceProxy = ""
        self.ac_match_type = ""
        self.ac_key_string = ""
        self.ac_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param v6_lsn_lid: {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}
    :param v6_glid: {"description": "Use global Limit ID (Specify global LID index)", "format": "number", "maximum": 1023, "minimum": 1, "not": "v6-lid", "type": "number"}
    :param ipv6_addr: {"type": "string", "description": "Specify IPv6 host or subnet", "format": "ipv6-address-plen"}
    :param v6_age: {"description": "Specify age in minutes", "minimum": 1, "type": "number", "maximum": 2000, "format": "number"}
    :param v6_lid: {"description": "Use Limit ID defined in template (Specify LID index)", "format": "number", "maximum": 31, "minimum": 1, "not": "v6-glid", "type": "number"}
    :param v6_lsn_radius_profile: {"description": "LSN RADIUS Profile Index", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-list"
        self.DeviceProxy = ""
        self.v6_lsn_lid = ""
        self.v6_glid = ""
        self.ipv6_addr = ""
        self.v6_age = ""
        self.v6_lid = ""
        self.v6_lsn_radius_profile = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dns(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dns_glid: {"description": "Use global Limit ID (Specify global LID index)", "format": "number", "maximum": 1023, "minimum": 1, "not": "dns-lid", "type": "number"}
    :param dns_match_type: {"enum": ["contains", "ends-with", "starts-with"], "type": "string", "description": "'contains': Domain contains another string; 'ends-with': Domain ends with another string; 'starts-with': Domain starts-with another string; ", "format": "enum"}
    :param dns_match_string: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Domain name", "format": "string"}
    :param dns_lid: {"description": "Use Limit ID defined in template (Specify LID index)", "format": "number", "maximum": 31, "minimum": 1, "not": "dns-glid", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns"
        self.DeviceProxy = ""
        self.dns_glid = ""
        self.dns_match_type = ""
        self.dns_match_string = ""
        self.dns_lid = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClassList(A10BaseClass):
    
    """Class Description::
    Configure classification list.

    Class class-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param file: {"description": "Create/Edit a class-list stored as a file", "format": "flag", "default": 0, "type": "number", "modify-not-allowed": 1, "optional": true}
    :param name: {"description": "Specify name of the class list", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param ipv4_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"lid": {"description": "Use Limit ID defined in template (Specify LID index)", "format": "number", "maximum": 31, "minimum": 1, "not": "glid", "type": "number"}, "glid": {"description": "Use global Limit ID (Specify global LID index)", "format": "number", "maximum": 1023, "minimum": 1, "not": "lid", "type": "number"}, "age": {"description": "Specify age in minutes", "minimum": 1, "type": "number", "maximum": 2000, "format": "number"}, "ipv4addr": {"type": "string", "description": "Specify IP address", "format": "ipv4-cidr"}, "lsn-lid": {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}, "lsn-radius-profile": {"description": "LSN RADIUS Profile Index", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}
    :param str_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"str": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify key string", "format": "string-rlx"}, "value-str": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify value string", "format": "string"}, "str-glid-dummy": {"default": 0, "not": "str-lid-dummy", "type": "number", "description": "Use global Limit ID", "format": "flag"}, "str-glid": {"description": "Global LID index", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}, "str-lid-dummy": {"default": 0, "not": "str-glid-dummy", "type": "number", "description": "Use Limit ID defined in template", "format": "flag"}, "str-lid": {"description": "LID index", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}, "optional": true}}]}
    :param ac_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ac-match-type": {"enum": ["contains", "ends-with", "equals", "starts-with"], "type": "string", "description": "'contains': String contains another string; 'ends-with': String ends with another string; 'equals': String equals another string; 'starts-with': String starts with another string; ", "format": "enum"}, "ac-key-string": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify key string", "format": "string-rlx"}, "ac-value": {"minLength": 1, "maxLength": 639, "type": "string", "description": "Specify value string", "format": "string-rlx"}, "optional": true}}]}
    :param ipv6_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"v6-lsn-lid": {"description": "LSN Limit ID (LID index)", "minimum": 1, "type": "number", "maximum": 1023, "format": "number"}, "v6-glid": {"description": "Use global Limit ID (Specify global LID index)", "format": "number", "maximum": 1023, "minimum": 1, "not": "v6-lid", "type": "number"}, "ipv6-addr": {"type": "string", "description": "Specify IPv6 host or subnet", "format": "ipv6-address-plen"}, "v6-age": {"description": "Specify age in minutes", "minimum": 1, "type": "number", "maximum": 2000, "format": "number"}, "v6-lid": {"description": "Use Limit ID defined in template (Specify LID index)", "format": "number", "maximum": 31, "minimum": 1, "not": "v6-glid", "type": "number"}, "optional": true, "v6-lsn-radius-profile": {"description": "LSN RADIUS Profile Index", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}}}]}
    :param dns: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dns-glid": {"description": "Use global Limit ID (Specify global LID index)", "format": "number", "maximum": 1023, "minimum": 1, "not": "dns-lid", "type": "number"}, "optional": true, "dns-match-type": {"enum": ["contains", "ends-with", "starts-with"], "type": "string", "description": "'contains': Domain contains another string; 'ends-with': Domain ends with another string; 'starts-with': Domain starts-with another string; ", "format": "enum"}, "dns-match-string": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Domain name", "format": "string"}, "dns-lid": {"description": "Use Limit ID defined in template (Specify LID index)", "format": "number", "maximum": 31, "minimum": 1, "not": "dns-glid", "type": "number"}}}]}
    :param type: {"description": "'ac': Make class-list type Aho-Corasick; 'dns': Make class-list type DNS; 'ipv4': Make class-list type IPv4; 'ipv6': Make class-list type IPv6; 'string': Make class-list type String; ", "format": "enum", "type": "string", "enum": ["ac", "dns", "ipv4", "ipv6", "string"], "modify-not-allowed": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/class-list/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "class-list"
        self.a10_url="/axapi/v3/class-list/{name}"
        self.DeviceProxy = ""
        self.A10WW_file = ""
        self.name = ""
        self.ipv4_list = []
        self.str_list = []
        self.ac_list = []
        self.ipv6_list = []
        self.dns = []
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ftp(A10BaseClass):
    
    """Class Description::
    FTP template.

    Class ftp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param to: {"description": "End range of FTP Active mode port", "format": "number", "type": "number", "maximum": 65534, "minimum": 1, "optional": true}
    :param active_mode_port: {"default": 0, "optional": true, "type": "number", "description": "Non-Standard FTP Active mode port", "format": "flag"}
    :param active_mode_port_val: {"description": "Non-Standard FTP Active mode port", "format": "number", "optional": true, "maximum": 65534, "minimum": 1, "not": "any", "type": "number"}
    :param name: {"description": "FTP template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param any: {"description": "Allow any FTP Active mode port", "format": "flag", "default": 0, "optional": true, "not": "active-mode-port-val", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/ftp/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ftp"
        self.a10_url="/axapi/v3/slb/template/ftp/{name}"
        self.DeviceProxy = ""
        self.to = ""
        self.active_mode_port = ""
        self.active_mode_port_val = ""
        self.name = ""
        self.A10WW_any = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param a1: {"minimum": 1, "type": "number", "maximum": 10, "format": "number"}
    :param a2: {"minLength": 1, "maxLength": 32, "type": "string", "description": "other fields for choice of a", "format": "string"}
    :param b1: {"minLength": 1, "maxLength": 32, "type": "string", "format": "string"}
    :param b2: {"description": "other fields for choice of b", "minimum": 1, "type": "number", "maximum": 100, "format": "number"}
    :param c2: {"type": "string", "description": "a compound key for choice of c", "format": "ipv4-netmask"}
    :param c3: {"minLength": 1, "maxLength": 128, "type": "string", "description": "other field for choice of c", "format": "string"}
    :param entry: {"enum": ["a", "b", "c"], "type": "string", "description": "a: \"a\"; b: \"b\"; c: \"c\"; ", "format": "enum"}
    :param c1: {"type": "string", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "list"
        self.DeviceProxy = ""
        self.a1 = ""
        self.a2 = ""
        self.b1 = ""
        self.b2 = ""
        self.c2 = ""
        self.c3 = ""
        self.entry = ""
        self.c1 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ListEnum1(A10BaseClass):
    
    """Class Description::
    Unit test CM list with different types of entries.

    Class list-enum-1 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"a1": {"minimum": 1, "type": "number", "maximum": 10, "format": "number"}, "a2": {"minLength": 1, "maxLength": 32, "type": "string", "description": "other fields for choice of a", "format": "string"}, "b1": {"minLength": 1, "maxLength": 32, "type": "string", "format": "string"}, "b2": {"description": "other fields for choice of b", "minimum": 1, "type": "number", "maximum": 100, "format": "number"}, "c2": {"type": "string", "description": "a compound key for choice of c", "format": "ipv4-netmask"}, "c3": {"minLength": 1, "maxLength": 128, "type": "string", "description": "other field for choice of c", "format": "string"}, "entry": {"enum": ["a", "b", "c"], "type": "string", "description": "a: \"a\"; b: \"b\"; c: \"c\"; ", "format": "enum"}, "c1": {"type": "string", "format": "ipv4-address"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cm-ut/list-enum-1`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "list-enum-1"
        self.a10_url="/axapi/v3/cm-ut/list-enum-1"
        self.DeviceProxy = ""
        self.A10WW_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Trunk(A10BaseClass):
    
    """Class Description::
    VRRP-A interface trunk.

    Class trunk supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param both: {"description": "both a router and server interface", "format": "flag", "default": 0, "optional": true, "not-list": ["router-interface", "server-interface"], "type": "number"}
    :param vlan: {"description": "VLAN ID", "format": "number", "optional": true, "maximum": 4094, "minimum": 1, "not": "no-heartbeat", "type": "number"}
    :param router_interface: {"description": "interface to upstream router", "format": "flag", "default": 0, "optional": true, "not-list": ["server-interface", "both"], "type": "number"}
    :param no_heartbeat: {"description": "do not send out heartbeat packet from this interface", "format": "flag", "default": 0, "optional": true, "not": "vlan", "type": "number"}
    :param server_interface: {"description": "interface to real server", "format": "flag", "default": 0, "optional": true, "not-list": ["router-interface", "both"], "type": "number"}
    :param trunk_val: {"description": "Ethernet Interface", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/interface/trunk/{trunk_val}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "trunk_val"]

        self.b_key = "trunk"
        self.a10_url="/axapi/v3/vrrp-a/interface/trunk/{trunk_val}"
        self.DeviceProxy = ""
        self.both = ""
        self.vlan = ""
        self.router_interface = ""
        self.no_heartbeat = ""
        self.server_interface = ""
        self.trunk_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Status: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Remote_IP: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Hash: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Encryption: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Responder_SPI: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Local_IP: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Lifetime: {"type": "number", "format": "number"}
    :param Initiator_SPI: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.Status = ""
        self.Remote_IP = ""
        self.Hash = ""
        self.Encryption = ""
        self.Responder_SPI = ""
        self.Local_IP = ""
        self.Lifetime = ""
        self.Initiator_SPI = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IkeGateway(A10BaseClass):
    
    """Class Description::
    Operational Status for the object ike-gateway.

    Class ike-gateway supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "IKE-gateway name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn/ike-gateway/{name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ike-gateway"
        self.a10_url="/axapi/v3/vpn/ike-gateway/{name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class LocalUriPolicy(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param local_uri: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify Local URI for caching (Specify URI pattern that the policy should be applied to, maximum 63 charaters)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "local-uri-policy"
        self.DeviceProxy = ""
        self.local_uri = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UriPolicy(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cache_action: {"enum": ["cache", "nocache"], "type": "string", "description": "'cache': Specify if certain URIs should be cached; 'nocache': Specify if certain URIs should not be cached; ", "format": "enum"}
    :param invalidate: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify if URI should invalidate chache entries matching pattern (pattern that would match entries to be invalidated (64 chars max))", "format": "string"}
    :param uri: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify URI for cache policy (Specify URI pattern that the policy should be applied to, maximum 63 charaters)", "format": "string-rlx"}
    :param cache_value: {"description": "Specify seconds that content should be cached, default is age specified in cache template", "minimum": 1, "type": "number", "maximum": 999999, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "uri-policy"
        self.DeviceProxy = ""
        self.cache_action = ""
        self.invalidate = ""
        self.uri = ""
        self.cache_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Cache(A10BaseClass):
    
    """Class Description::
    RAM caching template.

    Class cache supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param accept_reload_req: {"default": 0, "optional": true, "type": "number", "description": "Accept reload requests via cache-control directives in HTTP headers", "format": "flag"}
    :param name: {"description": "Specify cache template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param age: {"description": "Specify duration in seconds cached content valid, default is 3600 seconds (seconds that the cached content is valid (default 3600 seconds))", "format": "number", "default": 3600, "optional": true, "maximum": 999999, "minimum": 1, "type": "number"}
    :param disable_insert_via: {"default": 0, "optional": true, "type": "number", "description": "Disable insertion of via header in response served from RAM cache", "format": "flag"}
    :param disable_insert_age: {"default": 0, "optional": true, "type": "number", "description": "Disable insertion of age header in response served from RAM cache", "format": "flag"}
    :param local_uri_policy: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "local-uri": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify Local URI for caching (Specify URI pattern that the policy should be applied to, maximum 63 charaters)", "format": "string-rlx"}}}]}
    :param replacement_policy: {"description": "'LFU': LFU; ", "format": "enum", "default": "LFU", "type": "string", "enum": ["LFU"], "optional": true}
    :param min_content_size: {"description": "Minimum size (bytes) of response that can be cached - default 512", "format": "number", "default": 512, "optional": true, "maximum": 268435455, "minimum": 0, "type": "number"}
    :param max_content_size: {"description": "Maximum size (bytes) of response that can be cached - default 81920 (80KB)", "format": "number", "default": 81920, "optional": true, "maximum": 268435455, "minimum": 0, "type": "number"}
    :param max_cache_size: {"description": "Specify maximum cache size in megabytes, default is 80MB (RAM cache size in megabytes (default 80MB))", "format": "number", "default": 80, "optional": true, "maximum": 4096, "minimum": 1, "type": "number"}
    :param logging: {"description": "Specify logging template (Logging Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/logging"}
    :param remove_cookies: {"default": 0, "optional": true, "type": "number", "description": "Remove cookies in response and cache", "format": "flag"}
    :param verify_host: {"default": 0, "optional": true, "type": "number", "description": "Verify request using host before sending response from RAM cache", "format": "flag"}
    :param default_policy_nocache: {"default": 0, "optional": true, "type": "number", "description": "Specify default policy to be to not cache", "format": "flag"}
    :param uri_policy: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cache-action": {"enum": ["cache", "nocache"], "type": "string", "description": "'cache': Specify if certain URIs should be cached; 'nocache': Specify if certain URIs should not be cached; ", "format": "enum"}, "invalidate": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify if URI should invalidate chache entries matching pattern (pattern that would match entries to be invalidated (64 chars max))", "format": "string"}, "uri": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify URI for cache policy (Specify URI pattern that the policy should be applied to, maximum 63 charaters)", "format": "string-rlx"}, "optional": true, "cache-value": {"description": "Specify seconds that content should be cached, default is age specified in cache template", "minimum": 1, "type": "number", "maximum": 999999, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/cache/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "cache"
        self.a10_url="/axapi/v3/slb/template/cache/{name}"
        self.DeviceProxy = ""
        self.accept_reload_req = ""
        self.name = ""
        self.age = ""
        self.disable_insert_via = ""
        self.disable_insert_age = ""
        self.local_uri_policy = []
        self.replacement_policy = ""
        self.min_content_size = ""
        self.max_content_size = ""
        self.max_cache_size = ""
        self.logging = ""
        self.remove_cookies = ""
        self.verify_host = ""
        self.default_policy_nocache = ""
        self.uri_policy = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HttpAuthenticate(A10BaseClass):
    
    """Class Description::
    HTTP-authenticate Logon.

    Class http-authenticate supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param instance_list: {"minItems": 1, "items": {"type": "instance"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"retry": {"description": "Specify max. number of failure retry (1 ~ 32), default is 3", "format": "number", "default": 3, "optional": true, "maximum": 32, "minimum": 1, "type": "number"}, "name": {"description": "Specify HTTP-Authenticate logon name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "auth-method": {"type": "object", "properties": {"ntlm": {"type": "object", "properties": {"ntlm-enable": {"default": 0, "type": "number", "description": "Enable NTLM logon", "format": "flag"}}}, "negotiate": {"type": "object", "properties": {"negotiate-enable": {"default": 0, "type": "number", "description": "Enable SPENGO logon", "format": "flag"}}}, "basic": {"type": "object", "properties": {"new-pin-page": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new PIN page name for RSA-RADIUS", "format": "string-rlx"}, "basic-enable": {"default": 0, "type": "number", "description": "Enable Basic logon", "format": "flag"}, "next-token-variable": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify next-token variable name", "format": "string-rlx"}, "next-token-page": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify next-token page name for RSA-RADIUS", "format": "string-rlx"}, "basic-realm": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify realm for basic logon", "format": "string-rlx"}, "new-pin-variable": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new PIN variable name", "format": "string-rlx"}, "challenge-response-form": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify challenge-response form for RSA-RADIUS authentication", "format": "string"}}}}}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/logon/http-authenticate/instance/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/logon/http-authenticate`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "http-authenticate"
        self.a10_url="/axapi/v3/aam/authentication/logon/http-authenticate"
        self.DeviceProxy = ""
        self.instance_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TrustedKey(A10BaseClass):
    
    """Class Description::
    trusted key.

    Class trusted-key supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param key: {"description": "trusted key", "format": "number", "optional": false, "maximum": 65535, "minimum": 1, "type": "number", "$ref": "/axapi/v3/ntp/auth-key"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ntp/trusted-key/{key}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "key"]

        self.b_key = "trusted-key"
        self.a10_url="/axapi/v3/ntp/trusted-key/{key}"
        self.DeviceProxy = ""
        self.key = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class LacpPassthrough(A10BaseClass):
    
    """Class Description::
    Peer ports to forward received lacp packets.

    Class lacp-passthrough supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param peer_from: {"optional": false, "type": "number", "description": "Peer member to forward received LACP packets", "format": "interface"}
    :param peer_to: {"optional": false, "type": "number", "description": "Peer member to forward received LACP packets", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/lacp-passthrough/{peer_from}+{peer_to}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "peer_from","peer_to"]

        self.b_key = "lacp-passthrough"
        self.a10_url="/axapi/v3/network/lacp-passthrough/{peer_from}+{peer_to}"
        self.DeviceProxy = ""
        self.peer_from = ""
        self.peer_to = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param use_gslb_state: {"type": "number", "format": "number"}
    :param gslb_protocol: {"type": "number", "format": "number"}
    :param ip: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dynamic: {"type": "number", "format": "number"}
    :param manually_health_check: {"type": "number", "format": "number"}
    :param disabled: {"type": "number", "format": "number"}
    :param state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param service_ip: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param port_count: {"type": "number", "format": "number"}
    :param local_protocol: {"type": "number", "format": "number"}
    :param virtual_server: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.use_gslb_state = ""
        self.gslb_protocol = ""
        self.ip = ""
        self.dynamic = ""
        self.manually_health_check = ""
        self.disabled = ""
        self.state = ""
        self.service_ip = ""
        self.port_count = ""
        self.local_protocol = ""
        self.virtual_server = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceIp(A10BaseClass):
    
    """Class Description::
    Operational Status for the object service-ip.

    Class service-ip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param node_name: {"description": "Service-IP Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-num", "port-proto"], "properties": {"oper": {"type": "object", "properties": {"use_gslb_state": {"type": "number", "format": "number"}, "gslb-protocol": {"type": "number", "format": "number"}, "service-port": {"type": "number", "format": "number"}, "dynamic": {"type": "number", "format": "number"}, "tcp": {"type": "number", "format": "number"}, "disabled": {"type": "number", "format": "number"}, "state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "local-protocol": {"type": "number", "format": "number"}, "manually-health-check": {"type": "number", "format": "number"}}}, "port-proto": {"enum": ["tcp", "udp"], "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}, "port-num": {"description": "Port Number", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/service-ip/{node-name}/port/{port-num}+{port-proto}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/service-ip/{node_name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "service-ip"
        self.a10_url="/axapi/v3/gslb/service-ip/{node_name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.node_name = ""
        self.port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nm_response: {"description": "Responses from cache 304 Not Modified", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param rsp_type_304: {"description": "Responses from server 304 Not Modified", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param rsp_other: {"description": "Responses from cache Other", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param content_toosmall: {"description": "Policy Content Too Small", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param entry_create_failures: {"description": "Entry Create failures", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param nocache_match: {"description": "Policy URI nocache", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param content_toobig: {"description": "Policy Content Too Big", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param nc_res_header: {"description": "Not cacheable", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param miss: {"description": "Cache Misses", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param nc_req_header: {"description": "No-cache Request", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param replaced_entry: {"description": "Entry Replaced", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param aging_entry: {"description": "Entry Aged Out", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param mem_size: {"description": "Memory Used", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param rsp_deflate: {"description": "Responses from cache 200 OK - Deflate", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param invalidate_match: {"description": "Policy URI invalidate", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param match: {"description": "Policy URI cache", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param cleaned_entry: {"description": "Entry Cleaned", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param entry_num: {"description": "Entry Cached", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param total_req: {"description": "Total Requests", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param bytes_served: {"description": "Bytes Served", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param rv_success: {"description": "Revalidation Successes", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param rv_failure: {"description": "Revalidation Failures", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param rsp_gzip: {"description": "Responses from cache 200 OK - Gzip", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param hits: {"description": "Cache Hits", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param rsp_type_other: {"description": "Responses from server 200 OK - Other", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param rsp_type_CE: {"description": "Responses from server 200 OK - Chnk Enc", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param rsp_no_compress: {"description": "Responses from cache 200 OK - No Comp", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param rsp_type_CL: {"description": "Responses from server 200 OK - Cont Len", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param caching_req: {"description": "Cacheable Requests", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param ims_request: {"description": "IMS Requests", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.nm_response = ""
        self.rsp_type_304 = ""
        self.rsp_other = ""
        self.content_toosmall = ""
        self.entry_create_failures = ""
        self.nocache_match = ""
        self.content_toobig = ""
        self.nc_res_header = ""
        self.miss = ""
        self.nc_req_header = ""
        self.replaced_entry = ""
        self.aging_entry = ""
        self.mem_size = ""
        self.rsp_deflate = ""
        self.invalidate_match = ""
        self.match = ""
        self.cleaned_entry = ""
        self.entry_num = ""
        self.total_req = ""
        self.bytes_served = ""
        self.rv_success = ""
        self.rv_failure = ""
        self.rsp_gzip = ""
        self.hits = ""
        self.rsp_type_other = ""
        self.rsp_type_CE = ""
        self.rsp_no_compress = ""
        self.rsp_type_CL = ""
        self.caching_req = ""
        self.ims_request = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RcCacheGlobal(A10BaseClass):
    
    """Class Description::
    Statistics for the object rc-cache-global.

    Class rc-cache-global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/rc-cache-global/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rc-cache-global"
        self.a10_url="/axapi/v3/slb/rc-cache-global/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Sample(A10BaseClass):
    
    """Class Description::
    Configure filters for monitoring traffic (All traffic is monitored if no filters configured).

    Class sample supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ve_list: {"minItems": 1, "items": {"type": "ve"}, "uniqueItems": true, "array": [{"required": ["ve-num"], "properties": {"ve-num": {"description": "VE interface number", "format": "number", "optional": false, "maximum": 4094, "minimum": 2, "type": "number", "$ref": "/axapi/v3/interface/ve"}}}], "type": "array", "$ref": "/axapi/v3/netflow/monitor/{name}/sample/ve/{ve-num}"}
    :param nat_pool_list: {"minItems": 1, "items": {"type": "nat-pool"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"pool-name": {"description": "Name of nat pool", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/netflow/monitor/{name}/sample/nat-pool/{pool-name}"}
    :param ethernet_list: {"minItems": 1, "items": {"type": "ethernet"}, "uniqueItems": true, "array": [{"required": ["ifindex"], "properties": {"ifindex": {"optional": false, "$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet interface number", "format": "interface"}}}], "type": "array", "$ref": "/axapi/v3/netflow/monitor/{name}/sample/ethernet/{ifindex}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow/monitor/{name}/sample`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "sample"
        self.a10_url="/axapi/v3/netflow/monitor/{name}/sample"
        self.DeviceProxy = ""
        self.ve_list = []
        self.nat_pool_list = []
        self.ethernet_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpNexthopLif(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cpu_process_1: {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}
    :param lif: {"description": "LIF Interface (Logical tunnel interface number)", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}
    :param description_nexthop_lif: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}
    :param distance_nexthop_lif: {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nexthop-lif"
        self.DeviceProxy = ""
        self.cpu_process_1 = ""
        self.lif = ""
        self.description_nexthop_lif = ""
        self.distance_nexthop_lif = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpNexthopIpv4(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cpu_process_3: {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}
    :param description_nexthop_ip: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}
    :param ip_next_hop: {"type": "string", "description": "Forwarding router's address", "format": "ipv4-address"}
    :param distance_nexthop_ip: {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nexthop-ipv4"
        self.DeviceProxy = ""
        self.cpu_process_3 = ""
        self.description_nexthop_ip = ""
        self.ip_next_hop = ""
        self.distance_nexthop_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpNexthopTunnel(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param description_nexthop_tunnel: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}
    :param tunnel: {"description": "Tunnel interface (Tunnel interface number)", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}
    :param ip_next_hop_tunnel: {"type": "string", "description": "Forwarding router's address", "format": "ipv4-address"}
    :param distance_nexthop_tunnel: {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}
    :param cpu_process_2: {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nexthop-tunnel"
        self.DeviceProxy = ""
        self.description_nexthop_tunnel = ""
        self.tunnel = ""
        self.ip_next_hop_tunnel = ""
        self.distance_nexthop_tunnel = ""
        self.cpu_process_2 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpNexthopPartition(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param partition_name: {"minLength": 1, "maxLength": 14, "type": "string", "description": "Name of network partition", "format": "string"}
    :param vrid_num_in_partition: {"description": "Specify ha VRRP-A vrid", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}
    :param description_partition_vrid: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}
    :param description_nexthop_partition: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nexthop-partition"
        self.DeviceProxy = ""
        self.partition_name = ""
        self.vrid_num_in_partition = ""
        self.description_partition_vrid = ""
        self.description_nexthop_partition = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Rib(A10BaseClass):
    
    """Class Description::
    Establish static routes.

    Class rib supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_nexthop_lif: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cpu-process-1": {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}, "lif": {"description": "LIF Interface (Logical tunnel interface number)", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}, "description-nexthop-lif": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "distance-nexthop-lif": {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "optional": true}}]}
    :param ip_nexthop_ipv4: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "cpu-process-3": {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}, "description-nexthop-ip": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "ip-next-hop": {"type": "string", "description": "Forwarding router's address", "format": "ipv4-address"}, "distance-nexthop-ip": {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}}}]}
    :param ip_dest_addr: {"optional": false, "type": "string", "description": "Destination prefix", "format": "ipv4-address"}
    :param ip_nexthop_tunnel: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"description-nexthop-tunnel": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "tunnel": {"description": "Tunnel interface (Tunnel interface number)", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}, "ip-next-hop-tunnel": {"type": "string", "description": "Forwarding router's address", "format": "ipv4-address"}, "distance-nexthop-tunnel": {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "optional": true, "cpu-process-2": {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}}}]}
    :param ip_nexthop_partition: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"partition-name": {"minLength": 1, "maxLength": 14, "type": "string", "description": "Name of network partition", "format": "string"}, "vrid-num-in-partition": {"description": "Specify ha VRRP-A vrid", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "optional": true, "description-partition-vrid": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "description-nexthop-partition": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}}}]}
    :param ip_mask: {"optional": false, "type": "string", "description": "Destination prefix mask", "format": "ipv4-netmask-brief"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/route/rib/{ip_dest_addr}+{ip_mask}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ip_dest_addr","ip_mask"]

        self.b_key = "rib"
        self.a10_url="/axapi/v3/ip/route/rib/{ip_dest_addr}+{ip_mask}"
        self.DeviceProxy = ""
        self.ip_nexthop_lif = []
        self.ip_nexthop_ipv4 = []
        self.ip_dest_addr = ""
        self.ip_nexthop_tunnel = []
        self.ip_nexthop_partition = []
        self.ip_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ftp(A10BaseClass):
    
    """Class Description::
    FTP type.

    Class ftp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ftp: {"default": 0, "optional": true, "type": "number", "description": "FTP type", "format": "flag"}
    :param ftp_password_string: {"description": "Specify the user password, '' means empty passworddd", "format": "password", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param ftp_password: {"default": 0, "optional": true, "type": "number", "description": "Specify the user password", "format": "flag"}
    :param ftp_port: {"description": "Specify FTP port (Specify port number, default is 21)", "format": "number", "default": 21, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param ftp_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param ftp_username: {"description": "Specify the username", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/ftp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ftp"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/ftp"
        self.DeviceProxy = ""
        self.ftp = ""
        self.ftp_password_string = ""
        self.ftp_password = ""
        self.ftp_port = ""
        self.ftp_encrypted = ""
        self.ftp_username = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Spn_krb_success: {"description": "SPN Kerberos Success", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param Spn_krb_request: {"description": "SPN Kerberos Request", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Spn_krb_faiure: {"description": "SPN Kerberos Failure", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Spn_krb_success = ""
        self.Spn_krb_request = ""
        self.Spn_krb_faiure = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Instance(A10BaseClass):
    
    """Class Description::
    Statistics for the object instance.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify HTTP-Authenticate logon name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/logon/http-authenticate/instance/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/logon/http-authenticate/instance/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class LocalUriFile(A10BaseClass):
    
    """Class Description::
    Local URI files for http response.

    Class local-uri-file supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param local_uri_file: {"description": "Local URI files for http response", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param remote_file: {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param period: {"description": "Specify the period in second", "format": "number", "type": "number", "maximum": 31536000, "minimum": 60, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/export-periodic/local-uri-file/{local_uri_file}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "local_uri_file"]

        self.b_key = "local-uri-file"
        self.a10_url="/axapi/v3/export-periodic/local-uri-file/{local_uri_file}"
        self.DeviceProxy = ""
        self.local_uri_file = ""
        self.remote_file = ""
        self.use_mgmt_port = ""
        self.period = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ExcludeIp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exclude_ip_start: {"type": "string", "description": "Single IP address or IP address range start", "format": "ipv4-address"}
    :param exclude_ip_end: {"type": "string", "description": "Address range end", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "exclude-ip"
        self.DeviceProxy = ""
        self.exclude_ip_start = ""
        self.exclude_ip_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Pool(A10BaseClass):
    
    """Class Description::
    Configure CGNv6 NAT pool.

    Class pool supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param max_users_per_ip: {"description": "Number of users that can be assigned to a NAT IP", "format": "number", "optional": true, "maximum": 64512, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param group: {"description": "Share with a partition group (Partition Group Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param start_address: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure start IP address of NAT pool", "format": "ipv4-address"}
    :param vrid: {"description": "Configure VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param partition: {"description": "Share with a single partition (Partition Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 14, "type": "string"}
    :param netmask: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure mask for pool", "format": "ipv4-netmask-brief"}
    :param end_address: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure end IP address of NAT pool", "format": "ipv4-address"}
    :param shared: {"description": "Share this pool with other partitions (default: not shared)", "partition-visibility": "shared", "default": 0, "optional": true, "format": "flag", "modify-not-allowed": 1, "type": "number"}
    :param exclude_ip: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"exclude-ip-start": {"type": "string", "description": "Single IP address or IP address range start", "format": "ipv4-address"}, "optional": true, "exclude-ip-end": {"type": "string", "description": "Address range end", "format": "ipv4-address"}}}]}
    :param pool_name: {"description": "Specify pool name or pool group", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat/pool/{pool_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "pool_name"]

        self.b_key = "pool"
        self.a10_url="/axapi/v3/cgnv6/nat/pool/{pool_name}"
        self.DeviceProxy = ""
        self.max_users_per_ip = ""
        self.group = ""
        self.start_address = ""
        self.vrid = ""
        self.partition = ""
        self.netmask = ""
        self.end_address = ""
        self.shared = ""
        self.exclude_ip = []
        self.pool_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VipList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param metric_type_vip: {"default": "2", "enum": ["1", "2"], "type": "string", "description": "1: \"Set OSPF External Type 1 metrics\"; 2: \"Set OSPF External Type 2 metrics\"; ", "format": "enum"}
    :param tag_vip: {"type": "number", "description": "Set tag for routes redistributed into OSPF. help-val 32-bit tag value", "format": "number"}
    :param metric_vip: {"description": "OSPF default metric. help-val OSPF metric", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}
    :param route_map_vip: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference. help-val Pointer to route-map entries", "format": "string"}
    :param type_vip: {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "only-flagged: \"Selected Virtual IP (VIP)\"; only-not-flagged: \"Only not flagged\"; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip-list"
        self.DeviceProxy = ""
        self.metric_type_vip = ""
        self.tag_vip = ""
        self.metric_vip = ""
        self.route_map_vip = ""
        self.type_vip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipRedist(A10BaseClass):
    
    """Class Description::
    VIP redistribution.

    Class vip-redist supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vip_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"metric-type-vip": {"default": "2", "enum": ["1", "2"], "type": "string", "description": "1: \"Set OSPF External Type 1 metrics\"; 2: \"Set OSPF External Type 2 metrics\"; ", "format": "enum"}, "tag-vip": {"type": "number", "description": "Set tag for routes redistributed into OSPF. help-val 32-bit tag value", "format": "number"}, "metric-vip": {"description": "OSPF default metric. help-val OSPF metric", "minimum": 0, "type": "number", "maximum": 16777214, "format": "number"}, "route-map-vip": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference. help-val Pointer to route-map entries", "format": "string"}, "optional": true, "type-vip": {"enum": ["only-flagged", "only-not-flagged"], "type": "string", "description": "only-flagged: \"Selected Virtual IP (VIP)\"; only-not-flagged: \"Only not flagged\"; ", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/redistribute/vip/vip-redist`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vip-redist"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/redistribute/vip/vip-redist"
        self.DeviceProxy = ""
        self.vip_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Route(A10BaseClass):
    
    """Class Description::
    Establish static routes.

    Class route supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param rib_list: {"minItems": 1, "items": {"type": "rib"}, "uniqueItems": true, "array": [{"required": ["ip-dest-addr", "ip-mask"], "properties": {"ip-nexthop-lif": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cpu-process-1": {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}, "lif": {"description": "LIF Interface (Logical tunnel interface number)", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}, "description-nexthop-lif": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "distance-nexthop-lif": {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "optional": true}}]}, "ip-nexthop-ipv4": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "cpu-process-3": {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}, "description-nexthop-ip": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "ip-next-hop": {"type": "string", "description": "Forwarding router's address", "format": "ipv4-address"}, "distance-nexthop-ip": {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}}}]}, "ip-dest-addr": {"optional": false, "type": "string", "description": "Destination prefix", "format": "ipv4-address"}, "ip-nexthop-tunnel": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"description-nexthop-tunnel": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "tunnel": {"description": "Tunnel interface (Tunnel interface number)", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}, "ip-next-hop-tunnel": {"type": "string", "description": "Forwarding router's address", "format": "ipv4-address"}, "distance-nexthop-tunnel": {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "optional": true, "cpu-process-2": {"default": 0, "type": "number", "description": "CPU rather than HW handle this entity", "plat-neg-list": ["non-fpga", "soft-ax"], "format": "flag"}}}]}, "ip-nexthop-partition": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"partition-name": {"minLength": 1, "maxLength": 14, "type": "string", "description": "Name of network partition", "format": "string"}, "vrid-num-in-partition": {"description": "Specify ha VRRP-A vrid", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "optional": true, "description-partition-vrid": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "description-nexthop-partition": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}}}]}, "ip-mask": {"optional": false, "type": "string", "description": "Destination prefix mask", "format": "ipv4-netmask-brief"}}}], "type": "array", "$ref": "/axapi/v3/ip/route/rib/{ip-dest-addr}+{ip-mask}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/route`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "route"
        self.a10_url="/axapi/v3/ip/route"
        self.DeviceProxy = ""
        self.rib_list = []
        self.static = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param curr_req: {"description": "Current requests", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param total_fwd_bytes: {"description": "Total forward bytes", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param compression_miss: {"description": "Number of requests NOT compressed", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param fastest_rsp_time: {"description": "Fastest response time", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param total_fwd_pkts: {"description": "Total forward packets", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param total_mf_dns_pkts: {"description": "Total MF DNS packets", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param compression_miss_template_exclusion: {"description": "Compression miss template exclusion", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param total_dns_pkts: {"description": "Total DNS packets", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param peak_conn: {"description": "Peak connections", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param compression_bytes_after: {"description": "Data out of compression engine", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param toatal_tcp_conn: {"description": "Total TCP connections", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param total_req: {"description": "Total requests", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param compression_bytes_before: {"description": "Data into compression engine", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param last_rsp_time: {"description": "Last response time", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param curr_conn: {"description": "Current connections", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param total_rev_bytes: {"description": "Total reverse bytes", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param curr_conn_rate: {"description": "Current connection rate", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param compression_miss_no_client: {"description": "Compression miss no client", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param es_total_failure_actions: {"description": "Total failure actions", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param total_conn: {"description": "Total connections", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param total_rev_pkts: {"description": "Total reverse packets", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param total_l7_conn: {"description": "Total L7 connections", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param total_req_succ: {"description": "Total successful requests", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param total_l4_conn: {"description": "Total L4 connections", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param slowest_rsp_time: {"description": "Slowest response time", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param compression_hit: {"description": "Number of requests compressed", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.curr_req = ""
        self.total_fwd_bytes = ""
        self.compression_miss = ""
        self.fastest_rsp_time = ""
        self.total_fwd_pkts = ""
        self.total_mf_dns_pkts = ""
        self.compression_miss_template_exclusion = ""
        self.total_dns_pkts = ""
        self.peak_conn = ""
        self.compression_bytes_after = ""
        self.toatal_tcp_conn = ""
        self.total_req = ""
        self.compression_bytes_before = ""
        self.last_rsp_time = ""
        self.curr_conn = ""
        self.total_rev_bytes = ""
        self.curr_conn_rate = ""
        self.compression_miss_no_client = ""
        self.es_total_failure_actions = ""
        self.total_conn = ""
        self.total_rev_pkts = ""
        self.total_l7_conn = ""
        self.total_req_succ = ""
        self.total_l4_conn = ""
        self.slowest_rsp_time = ""
        self.compression_hit = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Port(A10BaseClass):
    
    """Class Description::
    Statistics for the object port.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param protocol: {"enum": ["tcp", "udp", "others", "diameter", "dns-tcp", "dns-udp", "fast-http", "fix", "ftp", "ftp-proxy", "http", "https", "mlb", "mms", "mysql", "mssql", "radius", "rtsp", "sip", "sip-tcp", "sips", "smpp-tcp", "spdy", "spdys", "smtp", "ssl-proxy", "tcp-proxy", "tftp"], "description": "'tcp': TCP LB service; 'udp': UDP Port; 'others': for no tcp/udp protocol, do IP load balancing; 'diameter': diameter port; 'dns-tcp': DNS service over TCP; 'dns-udp': DNS service over UDP; 'fast-http': Fast HTTP Port; 'fix': FIX Port; 'ftp': File Transfer Protocol Port; 'ftp-proxy': ftp proxy port; 'http': HTTP Port; 'https': HTTPS port; 'mlb': Message based load balancing; 'mms': Microsoft Multimedia Service Port; 'mysql': mssql port; 'mssql': mssql; 'radius': Radius Port; 'rtsp': Real Time Streaming Protocol Port; 'sip': Session initiation protocol over UDP; 'sip-tcp': Session initiation protocol over TCP; 'sips': Session initiation protocol over TLS; 'smpp-tcp': SMPP service over TCP; 'spdy': spdy port; 'spdys': spdys port; 'smtp': SMTP Port; 'ssl-proxy': Generic SSL proxy; 'tcp-proxy': Generic TCP proxy; 'tftp': TFTP Port; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}
    :param port_number: {"description": "Port", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/virtual-server/{name}/port/{port_number}+{protocol}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_number","protocol"]

        self.b_key = "port"
        self.a10_url="/axapi/v3/slb/virtual-server/{name}/port/{port_number}+{protocol}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.protocol = ""
        self.port_number = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


